/*      $Id: spinning_cursor.h 11914 2004-08-22 22:18:50Z olivier $
 
        This program is free software; you can redistribute it and/or modify
        it under the terms of the GNU General Public License as published by
        the Free Software Foundation; either version 2, or (at your option)
        any later version.
 
        This program is distributed in the hope that it will be useful,
        but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
        GNU General Public License for more details.
 
        You should have received a copy of the GNU General Public License
        along with this program; if not, write to the Free Software
        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
        mozilla  - (c) 1998 mozilla.org
        xfwm4    - (c) 2002-2004 Olivier Fourdan
 
 */

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#ifndef INC_SPINNING_CURSOR_H
#define INC_SPINNING_CURSOR_H

#include <X11/Xlib.h>

Cursor cursorCreateSpinning (Display * dpy);

#endif /* INC_SPINNING_CURSOR_H */
